==> e2fyi-utils-0.1.0a4.tar.gz: e2fyi-utils-0.1.0a4/setup.py <==
#!/usr/bin/env python
# noqa
# pylint: skip-file
"""The setup script."""
from setuptools import setup

with open("requirements.txt", "r") as filein:
    requirements = filein.readlines()

with open("requirements-dev.txt", "r") as filein:
    test_requirements = filein.readlines()

with open("version.txt", "r") as filein:
    version = filein.read()

with open("README.md", "r") as filein:
    readme = filein.read()


setup_requirements: list = [
    "setuptools >= 41.0.0",
    # python3 specifically requires wheel 0.26
    'wheel; python_version < "3"',
    'wheel >= 0.26; python_version >= "3"',
]

setup(
    author="eterna2",
    author_email="eterna2@hotmail.com",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    description="General utils for interacting with aws resources.",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/e2fyi/py-utils",
    include_package_data=True,
    package_data={
        "": [
            "version.txt",
            "requirements.txt",
            "requirements-dev.txt",
            "test.py",
            "README.md",
        ]
    },
    keywords="util aws s3 boto3 upload",
    name="e2fyi-utils",
    packages=["e2fyi.utils", "e2fyi.utils.aws", "e2fyi.utils.core", "e2fyi.utils.io"],
    setup_requires=setup_requirements,
    python_requires=">=3.6",
    install_requires=requirements,
    test_suite="e2fyi",
    tests_require=test_requirements,
    version=version,
    zip_safe=False,
)

==> e2fyi-utils-0.2.0.post1.tar.gz: e2fyi-utils-0.2.0.post1/setup.py <==
#!/usr/bin/env python
# noqa
# pylint: skip-file
"""The setup script."""
from setuptools import setup

with open("requirements.txt", "r") as filein:
    requirements = filein.readlines()

with open("requirements-dev.txt", "r") as filein:
    test_requirements = filein.readlines()

with open("version.txt", "r") as filein:
    version = filein.read()

with open("README.md", "r") as filein:
    readme = filein.read()


setup_requirements: list = [
    "setuptools >= 41.0.0",
    # python3 specifically requires wheel 0.26
    'wheel; python_version < "3"',
    'wheel >= 0.26; python_version >= "3"',
]

setup(
    author="eterna2",
    author_email="eterna2@hotmail.com",
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "Intended Audience :: Developers",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    description="General utils for interacting with aws resources.",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/e2fyi/py-utils",
    include_package_data=True,
    package_data={
        "": [
            "version.txt",
            "requirements.txt",
            "requirements-dev.txt",
            "test.py",
            "README.md",
        ]
    },
    keywords="util aws s3 boto3 upload",
    name="e2fyi-utils",
    packages=["e2fyi.utils", "e2fyi.utils.aws", "e2fyi.utils.core"],
    setup_requires=setup_requirements,
    python_requires=">=3.6",
    install_requires=requirements,
    test_suite="e2fyi",
    tests_require=test_requirements,
    version=version,
    zip_safe=False,
)
